# Copyright 2009-2011 Canonical Ltd.
#
# This file is part of wsgi-oops.
#
# wsgi-oops is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License version 3
# as published by the Free Software Foundation.
#
# wsgi-oops is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with wsgi-oops.  If not, see <http://www.gnu.org/licenses/>.

"""Tests for canoncal.oops.reporter."""
import os
import unittest

from canonical.oops.tests import testcase
from canonical.oops.oops import OOPS
from canonical.oops.reporter import OOPSReporter


class ReporterTests(testcase.OopsTestCase):
    """ simple test of wsgi oops just test for all ok and error """

    def setUp(self):
        """Set up an OOPSReporter instance."""
        super(ReporterTests, self).setUp()
        self.reporter = OOPSReporter(self.tmp_dir, thread_local=False)

    def test_reporter_context(self):
        """Test that we can open a reporter context."""
        with self.reporter.open_request():
            pass

    def test_reporter_context_oops(self):
        """Test that we can access the oops in the context."""
        with self.reporter.open_request() as oops:
            self.assertEqual(type(oops), OOPS)

    def test_oops_no_error(self):
        """Test that we don't want the oops if no error in the context."""

        def run_with_context():
            """Run in the context and return the oops."""
            with self.reporter.open_request() as oops:
                return oops

        oops = run_with_context()
        self.assert_(not oops.wanted)

    def test_oops_with_error(self):
        """Test what happens when we raise an error within a context."""


        class UniqueException(Exception):
            """A unique exception class for this test."""

            def __init__(self, oops):
                """Save the oops."""
                self.oops = oops


        try:
            with self.reporter.open_request() as oops:
                raise UniqueException(oops)
        except UniqueException, e:
            self.assert_(e.oops.wanted)
